.. raw:: html

  <script>
    window.MathJax = {
      tex: {
        inlineMath: [['\\(', '\\)']],
        macros: {
          trans: ['{#1}^\\intercal',1],
          vec: ['\\boldsymbol{#1}',1],
          oper: ['\\mathbf{#1}',1],
          dvol: [`{\\rm d}^{#1}\\hspace{-2pt}#2`, 2],
          Sha: [`\\mbox{Ш}`],
          sinc: [`\\mbox{sinc}`],
          esp: [`\\mbox{E}\\left\\{#1\\right\\}`, 1]
        }
      }
    };
  </script>

.. raw:: latex

  \def\trans#1{{#1}^\intercal}
  \def\vec#1{{\boldsymbol{#1}}}
  \def\oper#1{\mathbf{#1}}
  \def\dvol#1#2{{\rm d}^{#1}\hspace{-2pt}#2}
  \def\sinc{\mbox{sinc}}
  \def\esp#1{\mbox{E}\left\{#1\right\}}
